#ifndef __SETUP_HEADER
#define __SETUP_HEADER

/*
 * SETUP.h
 * Variables created by SETUP.
 *
 * Automatically generated file.
 * EDIT AT YOUR OWN RISK
 */

#ifndef LINUX
  #define LINUX 1
#endif /* LINUX */

#ifndef LINUX_1
  #define LINUX_1 1
#endif /* LINUX_1 */

#ifndef LINUX_1_3_3
  #define LINUX_1_3_3 1
#endif /* LINUX_1_3_3 */

#ifndef POSIX
  #define POSIX 1
#endif /* POSIX */

#define SETUP_SHELL		/usr/bin/bash
  /* The /bin/sh-compatible shell recommended by SETUP */
#define szAuthorName		Stuart Herbert
#define szAuthorEmail		S.Herbert@sheffield.ac.uk
  /* The name and email address of the product's author */
#define szTitle			Monsanto-NQS\n
#define szVersion		3.50.05
#define szReleaseDate		Wed Jul 12 13:21:13 GMT 1995
#define szCopyright		Copyright (c) 1985 COSMIC\nCopyright (c) 1992, 1993, 1994 John Roman, Monsanto Company\nCopyright (c) 1994, 1995 The University of Sheffield\nAll rights reserved.
#define szPreviousVersion	3.37
#define szBuildNo		5
#define DEBUG			1
  /* This is a test release, so we enable debugging by default */

#endif /* __SETUP_HEADER */
