#ifndef ___CONFIG_HEADER
#define ___CONFIG_HEADER

/*
 * This is an automatically-generated file,
 * which is included by the C source code.
 *
 * Edit at your own risk.
 */

/*
 * Configuring the generic internal NQS library.
 */

/*
 * Debugging support.
 */

/*
 * Monsanto-NQS now uses the syslogd(8) daemon for logging messages.
 * 
 * syslogd(8) can be configured to send messages from different facilities
 * to different places.  Monsanto-NQS can be configured to be any of the
 * facilities LOCAL0-7.  We STRONGLY recommend that you configure syslogd
 * so that messages from Monsanto-NQS are stored in a separate file from
 * messages from other facilities; this will assist in any debugging.
 */

#define CONFIG_SYSLOG_FACILITY "LOG_LOCAL0"

#endif /* __nqs_generic_CONFIG_HEADER */
